==> v0.01.zip: hugo/content/de/Treffen.md <==
---
title: "Treffen"
date: 2021-02-04T10:05:56+01:00
draft: false
---
[![English](/eng.png)](/en/Meetup)

**Die Treffen (Stammtisch und Vorträge) finden bis auf weiteres aufgrund der aktuellen Situation ausschließlich virtuell statt. Sobald diese wieder durchgeführt werden, erfahrt ihr es hier!**

Angestrebt ist, dass wir am Dienstagstermin einen Vortrag präsentieren. [Vortragsvorschläge](/de/Vorschlaege) bitte auf der [Mailingliste](/de/Mailingliste) posten.

-----

### Unsere Treffpunkte - So kommt man hin

**Sandelmühle**    
An der Sandelmühle 35   
60439 Frankfurt   

Telefon Restaurant: 069 / 575742

[Homepage](http://www.sandelmuehle.de/restaurant/restaurant-frankfurt/) [Speisekarte](http://www.sandelmuehle.de/restaurant/speisenkarte/)

Übersichtskarte Heddernheim bei [OpenStreetMap](http://www.openstreetmap.org/?lat=50.16356&lon=8.64975&zoom=16&layers=B000FTF) und [Google Maps](http://maps.google.com/maps?f=q&source=s_q&hl=de&geocode=&q=Hotel+%26+Restaurant+Sandelm%C3%BChle&sll=37.0625,-95.677068&sspn=29.219963,45.263672&ie=UTF8&hq=Hotel&hnear=Frankfurt,+Frankfurt+am+Main,+Hesse,+Germany&ll=50.163498,8.649309&spn=0.01365,0.033023&t=h&z=16&iwloc=A&cid=1225964577310492751)

Parkplätze sind vor dem Haus vorhanden.

Übersichtskarte der öffentlichen Verkehrsmittel für die Sandelmühle bei [www.öpnvkarte.de](http://www.öpnvkarte.de/?zoom=16&lat=50.16389&lon=8.64868&layers=BT)

Aus Richtung Bad Homburg:

U-Bahn » U2, Haltestelle: Sandelmühle

Der die Schienen querenden Straße "An der Sandelmühle" Richtung Nidda etwa 200m folgen.

Aus der Stadt:

U-Bahn » U1, U2, U3 oder U8, Haltestelle: Heddernheim

In östlicher Richtung den Hinterausgang der U-Bahn-Station nehmen. Nach links wenden und die Straße "An der Sandelmühle" etwa 150m folgen.

-----

**Saalbau Gallus**    
Frankenallee 111   
60326 Frankfurt am Main   

[Saalbau-Homepage](https://www.saalbau.com/raumangebot/detail/?SAALBAU-Gallus&objekt=52)

Übersichtskarte Gallus bei [OpenStreetMap](http://www.openstreetmap.org/?lat=50.104458&lon=8.641691&zoom=17&layers=B000FTF) und [Google Maps](http://maps.google.com/maps?f=q&source=s_q&hl=de&geocode=&q=Saalbau+Gallus&ie=UTF8&hq=Saalbau+Gallus&hnear=&ll=50.104458,8.641691&spn=0.006661,0.016512&t=h&z=16&iwloc=A)

Übersichtskarte der öffentlichen Verkehrsmittel für den Saalbau Gallus bei [www.öpnvkarte.de](http://www.öpnvkarte.de/?zoom=16&lat=50.104458&lon=8.641691&layers=BT)

-----

## Ein paar Worte zu den Treffen!

Jeder kann kommen, ist aber für sich selbst verantwortlich. Viele kommen um ihre Erfahrungen auszutauschen, haste nichts zum tauschen, musste halt nur lauschen.

Wer seinen Rechner mitbringen will, weil er mal das Pinguinsystem installieren möchte oder anders ausprobieren möchte oder weil er Probleme mit einem bestimmten Programm hat, kann dies gerne tun. Es wird aber in jedem Fall empfohlen, dies vorher in der [Mailingliste](/de/Mailingliste) anzusprechen, damit man nicht nachher ohne Installationsmedium beim Treffen sitzt.

Ansonsten gibt es immer einige Helfer, die sich auch schnell streiten, wer denn zuerst die Tastatur massakrieren darf.

Die Vorträge finden in "**Nichtraucherräumen**" statt. Raucher müssen den Raum verlassen, um zu rauchen!

**Die Sandelmühle stellt einen freien Internetzugang per WLAN zur Verfügung.**

### Im Saalbau Gallus

Das Treffen findet im Seminarraum 4 statt. Die Vorträge beginnen in der Regel gegen 19 Uhr. Es kann jegliche Form von Hardware mitgebracht werden. Ist der Vortrag beendet, kann in Clubatmosphäre diskutiert bzw. sich um die mitgebrachte Hardware gekümmert werden. Üblicherweise begeben wir uns im Anschluss noch in eine der Gaststätten in der Nähe zum Weiterdiskutieren; ~~derzeit "Zum Hufnagel", Hufnagelstraße 12a, 60326 Frankfurt a.M.~~ Das ehemalige "Zum Hufnagel" ist nun ein Chinesisches Restaurant und heisst nun "Asian Flavors". Müssen wir mal austesten ...

==> v0.03.zip: hugo/content/de/Treffen.md <==
---
title: "Treffen"
date: 2021-02-04T10:05:56+01:00
draft: false
---
[![English](/eng.png#floatright)](/en/Meetup)

**Die Treffen (Stammtisch und Vorträge) finden bis auf weiteres aufgrund der aktuellen Situation ausschließlich virtuell statt. Sobald diese wieder durchgeführt werden, erfahrt ihr es hier!**

Angestrebt ist, dass wir am Dienstagstermin einen Vortrag präsentieren. [Vortragsvorschläge](/de/Vorschlaege) bitte auf der [Mailingliste](/de/Mailingliste) posten.

-----

### Unsere Treffpunkte - So kommt man hin

**Sandelmühle**    
An der Sandelmühle 35   
60439 Frankfurt   

Telefon Restaurant: 069 / 575742

{{<tabref href="http://www.sandelmuehle.de/restaurant/restaurant-frankfurt" title="Homepage">}} {{<tabref href="http://www.sandelmuehle.de/restaurant/speisenkarte"  title="Speisekarte">}}


Übersichtskarte Heddernheim bei {{<tabref href="http://www.openstreetmap.org/?lat=50.16356&lon=8.64975&zoom=16&layers=B000FTF" title="OpenStreetMap">}} und {{<tabref href="http://maps.google.com/maps?f=q&source=s_q&hl=de&geocode=&q=Hotel+%26+Restaurant+Sandelm%C3%BChle&sll=37.0625,-95.677068&sspn=29.219963,45.263672&ie=UTF8&hq=Hotel&hnear=Frankfurt,+Frankfurt+am+Main,+Hesse,+Germany&ll=50.163498,8.649309&spn=0.01365,0.033023&t=h&z=16&iwloc=A&cid=1225964577310492751" title="Google Maps">}}

Parkplätze sind vor dem Haus vorhanden.

Übersichtskarte der öffentlichen Verkehrsmittel für die Sandelmühle bei {{<tabref href="http://www.öpnvkarte.de/?zoom=16&lat=50.16389&lon=8.64868&layers=BT" title="www.öpnvkarte.de">}}

Aus Richtung Bad Homburg:

U-Bahn » U2, Haltestelle: Sandelmühle

Der die Schienen querenden Straße "An der Sandelmühle" Richtung Nidda etwa 200m folgen.

Aus der Stadt:

U-Bahn » U1, U2, U3 oder U8, Haltestelle: Heddernheim

In östlicher Richtung den Hinterausgang der U-Bahn-Station nehmen. Nach links wenden und die Straße "An der Sandelmühle" etwa 150m folgen.

-----

**Saalbau Gallus**    
Frankenallee 111   
60326 Frankfurt am Main   

{{<tabref href="https://www.saalbau.com/raumangebot/detail/?SAALBAU-Gallus&objekt=52" title="Saalbau-Homepage">}}

Übersichtskarte Gallus bei  {{<tabref href="http://www.openstreetmap.org/?lat=50.104458&lon=8.641691&zoom=17&layers=B000FTF" title="OpenStreetMap">}} and {{<tabref href="http://maps.google.com/maps?f=q&source=s_q&hl=de&geocode=&q=Saalbau+Gallus&ie=UTF8&hq=Saalbau+Gallus&hnear=&ll=50.104458,8.641691&spn=0.006661,0.016512&t=h&z=16&iwloc=A" title="Google Maps">}}

Übersichtskarte der öffentlichen Verkehrsmittel für den Saalbau Gallus bei {{<tabref href="http://www.öpnvkarte.de/?zoom=16&lat=50.104458&lon=8.641691&layers=BT" title="www.öpnvkarte.de">}}

-----

## Ein paar Worte zu den Treffen!

Jeder kann kommen, ist aber für sich selbst verantwortlich. Viele kommen um ihre Erfahrungen auszutauschen, haste nichts zum tauschen, musste halt nur lauschen.

Wer seinen Rechner mitbringen will, weil er mal das Pinguinsystem installieren möchte oder anders ausprobieren möchte oder weil er Probleme mit einem bestimmten Programm hat, kann dies gerne tun. Es wird aber in jedem Fall empfohlen, dies vorher in der [Mailingliste](/de/Mailingliste) anzusprechen, damit man nicht nachher ohne Installationsmedium beim Treffen sitzt.

Ansonsten gibt es immer einige Helfer, die sich auch schnell streiten, wer denn zuerst die Tastatur massakrieren darf.

Die Vorträge finden in "**Nichtraucherräumen**" statt. Raucher müssen den Raum verlassen, um zu rauchen!

**Die Sandelmühle stellt einen freien Internetzugang per WLAN zur Verfügung.**

### Im Saalbau Gallus

Das Treffen findet im Seminarraum 4 statt. Die Vorträge beginnen in der Regel gegen 19 Uhr. Es kann jegliche Form von Hardware mitgebracht werden. Ist der Vortrag beendet, kann in Clubatmosphäre diskutiert bzw. sich um die mitgebrachte Hardware gekümmert werden. Üblicherweise begeben wir uns im Anschluss noch in eine der Gaststätten in der Nähe zum Weiterdiskutieren; ~~derzeit "Zum Hufnagel", Hufnagelstraße 12a, 60326 Frankfurt a.M.~~ Das ehemalige "Zum Hufnagel" ist nun ein Chinesisches Restaurant und heisst nun "Asian Flavors". Müssen wir mal austesten ...
